package com.seostella.toggleview.view;

import com.seostella.toggleview.R;

import android.content.Context;
import android.content.res.TypedArray;
import android.util.AttributeSet;
import android.view.View;
import android.widget.TextView;

public class ToggleThree extends Toggle {
	protected String centerText;
	
	protected TextView centerTextView;
	
	protected int centerDrawable;
	
	protected boolean centerOptionSelected = false;
	protected boolean rightOptionSelected = false;
	
	public ToggleThree(Context context) {
		super(context);
	}

	public ToggleThree(Context context, AttributeSet attrs, int defStyle) {
		super(context, attrs, defStyle);
	}

	public ToggleThree(Context context, AttributeSet attrs) {
		super(context, attrs);
	}
	
	public void setCenterDrawable( int drawable ){
		this.centerDrawable = drawable;
	}
	
	@Override
	protected void init( Context context, AttributeSet attrs ){
		super.init(context, attrs);
		
		final TypedArray a = getContext().obtainStyledAttributes(attrs,
		        R.styleable.Toggle);
		
		centerText = a.getString( R.styleable.Toggle_centerText);
		
		setLeftDrawable( R.drawable.toggle3_left );
		setRightDrawable( R.drawable.toggle3_right );
		setCenterDrawable( R.drawable.toggle3_center );
	}
	
	@Override
	protected int getView(){
		return R.layout.toggle_three;
	}
	
	@Override
	protected void initTextViews(){
		super.initTextViews();
		
		centerTextView = (TextView) this.findViewById(R.id.cenger_label);
		centerTextView.setText( centerText );
		centerTextView.setOnClickListener( centerTextOnClickListener );
	}
	
	private OnClickListener centerTextOnClickListener = new OnClickListener() {
		
		@Override
		public void onClick(View v) {
			selectCenter();
		}
	};
	
	protected void selectCenter(){
		if( !centerOptionSelected ){
			this.setBackgroundResource( centerDrawable );
			leftTextView.setTextColor( nonActiveColor );
			centerTextView.setTextColor( activeColor );
			rightTextView.setTextColor( nonActiveColor );
			
			leftOptionSelected = false;
			centerOptionSelected = true;
			rightOptionSelected = false;
			
			if( onStateChangeListener != null ){
				onStateChangeListener.stateChanged();
			}
		}
	}
	
	@Override
	protected void selectLeft(){
		super.selectLeft();
		centerTextView.setTextColor( nonActiveColor );
		
		centerOptionSelected = false;
		rightOptionSelected = false;
	}
	
	@Override
	protected void selectRight(){
		super.selectRight();
		centerTextView.setTextColor( nonActiveColor );
		
		centerOptionSelected = false;
		rightOptionSelected = true;
	}
	
	public void setLeftOptionSelected(){
		selectLeft();
	}
	
	public void setRightOptionSelected( boolean selected ){
		selectRight();
	}
	
	public boolean isRightOptionSelected(){
		return rightOptionSelected;
	}
	
	public void setCenterOptionSelected( boolean selected ){
		selectCenter();
	}
	
	public boolean isCenterOptionSelected(){
		return centerOptionSelected;
	}
}
